'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pluginLogger = require('liferay-npm-build-tools-common/lib/plugin-logger');

var _pluginLogger2 = _interopRequireDefault(_pluginLogger);

var _project = require('liferay-npm-build-tools-common/lib/project');

var _project2 = _interopRequireDefault(_project);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * © 2017 Liferay, Inc. <https://liferay.com>
 *
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

var savedProjectPath = _project2.default.dir.asNative;

beforeEach(function () {
	_project2.default.loadFrom(_path2.default.join(__dirname, '..', '..'));
});

afterEach(function () {
	_project2.default.loadFrom(savedProjectPath);
});

var TEST_JS = 'const x = 1;';

it('logs results correctly', function () {
	var context = {
		content: TEST_JS,
		filePath: 'file.js',
		log: new _pluginLogger2.default(),
		extraArtifacts: {}
	};

	(0, _index2.default)(context, { presets: ['es2015'] });

	expect(context.log.messages).toEqual([{
		level: 'info',
		source: 'babel-loader',
		things: ['Transpiled file']
	}]);
});

it('correctly transpiles JS code', function () {
	var context = {
		content: TEST_JS,
		filePath: 'file.js',
		log: new _pluginLogger2.default(),
		extraArtifacts: {}
	};

	var result = (0, _index2.default)(context, { presets: ['es2015'] });

	expect(result).toEqual('"use strict";\n\nvar x = 1;');

	expect(Object.keys(context.extraArtifacts)).toEqual(['file.js.map']);
	expect(JSON.parse(context.extraArtifacts['file.js.map'])).toEqual({
		version: 3,
		sources: ['file.js'],
		names: ['x'],
		mappings: ';;AAAA,IAAMA,IAAI,CAAV',
		file: 'file.js',
		sourcesContent: ['const x = 1;']
	});
});
//# sourceMappingURL=index.test.js.map