'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

exports.default = function (context, config) {
	var content = context.content,
	    filePath = context.filePath,
	    log = context.log,
	    sourceMap = context.sourceMap;


	var babelConfig = Object.assign({
		filenameRelative: filePath,
		inputSourceMap: sourceMap
	}, config);

	// Tune babel config
	babelConfig.babelrc = false;
	babelConfig.only = '**/*';
	if (babelConfig.sourceMaps === undefined) {
		babelConfig.sourceMaps = true;
	}

	// Intercept presets and plugins to load them from project
	babelConfig.plugins = loadBabelPlugins(babelConfig.presets || [], babelConfig.plugins || []);
	delete babelConfig.presets;

	var result = babel.transform(content, babelConfig);

	context.sourceMap = result.map;
	context.extraArtifacts[filePath + '.map'] = JSON.stringify(result.map);

	log.info('babel-loader', 'Transpiled file');

	return result.code;
};

var _babelCore = require('babel-core');

var babel = _interopRequireWildcard(_babelCore);

var _project = require('liferay-npm-build-tools-common/lib/project');

var _project2 = _interopRequireDefault(_project);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } } /**
                                                                                                                                                                                                     * © 2017 Liferay, Inc. <https://liferay.com>
                                                                                                                                                                                                     *
                                                                                                                                                                                                     * SPDX-License-Identifier: LGPL-3.0-or-later
                                                                                                                                                                                                     */

/**
 * @param {object} context loader's context
 * @param {object} config a .babelrc like configuration object
 * @return {string} the processed file content
 */


/**
 * Load Babel plugins from a given array of presets and plugins.
 * @param {Array} presets an array of Babel preset names as defined by .babelrc
 * @param {Array} plugins an array of Babel plugins names as defined by .babelrc
 * @return {Array} the instantiated Babel plugins
 */
function loadBabelPlugins(presets, plugins) {
	var _ref;

	return (_ref = []).concat.apply(_ref, _toConsumableArray(presets.map(function (preset) {
		var presetModule = void 0,
		    presetName = void 0;

		try {
			presetName = 'babel-preset-' + preset;
			presetModule = _project2.default.require(presetName);
		} catch (err) {
			presetName = preset;
			presetModule = _project2.default.require(presetName);
		}

		if (presetModule === undefined) {
			throw new Error('Babel preset \'' + presetName + '\' does not export anything');
		}

		if (presetModule.default !== undefined) {
			presetModule = presetModule.default;
		}

		if (presetModule.plugins === undefined && typeof presetModule !== 'function') {
			throw new Error('Babel preset \'' + presetName + '\' does not export a ' + 'valid function or plugins object');
		}

		return presetModule.plugins || presetModule().plugins;
	}))).concat(plugins);
}
//# sourceMappingURL=index.js.map